.. si-prefix documentation master file, created by
   sphinx-quickstart on Mon Aug 22 12:39:50 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to si-prefix's documentation!
=====================================

.. include:: README.rst

-----------------

API
---

.. automodule:: si_prefix
    :members:
    :undoc-members:
    :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
